@@ -2,7 +2,7 @@ from logging.config import dictConfig
 
 from flask import Flask, request
 
-from cloud_spi_log import log_config
+from py_base_framework.cloud_spi_log import log_config
 
 dictConfig(log_config)
 
